Class: URBANopt::Scenario::Extension

Inherits:
OpenStudio::Extension::Extension
  • Object
show all
Defined in:
lib/urbanopt/scenario/extension.rb

Instance Method Summary collapse

Constructor Details

#initializeExtension

Returns a new instance of Extension.



11
12
13
14
# File 'lib/urbanopt/scenario/extension.rb', line 11

def initialize
  super
  @root_dir = File.absolute_path(File.join(File.dirname(__FILE__), '..', '..', '..'))
end

Instance Method Details

#doc_templates_dirObject

Doc templates are common files like copyright files which are used to update measures and other code. Doc templates will only be applied to measures in the current repository.

[return:] Absolute path of the doc templates dir or nil if there is none.



35
36
37
# File 'lib/urbanopt/scenario/extension.rb', line 35

def doc_templates_dir
  return File.absolute_path(File.join(@root_dir, 'doc_templates'))
end

#files_dirObject

Relevant files such as weather data, design days, etc.

[return:] Absolute path of the files or nil if there is none, used when configuring OSWs



26
27
28
# File 'lib/urbanopt/scenario/extension.rb', line 26

def files_dir
  return nil
end

#measures_dirObject

[return:] Absolute path of the measures or nil if there is none, can be used when configuring OSWs.



18
19
20
# File 'lib/urbanopt/scenario/extension.rb', line 18

def measures_dir
  return File.absolute_path(File.join(@root_dir, 'lib', 'measures'))
end